@@ -15,14 +15,14 @@ from contextlib import contextmanager
 from contextvars import ContextVar
 from pathlib import Path
 from types import ModuleType
-from typing import TYPE_CHECKING, Any, List, TypeVar, Union
+from typing import TYPE_CHECKING, Any, TypeVar, Union
 
 if TYPE_CHECKING:
     import socket
     import threading
-    from collections.abc import Callable, Iterable, Iterator
+    from collections.abc import Callable, Iterable, Iterator, Sequence
 
-    _ModuleList = Union[List[Union[str, ModuleType]], None]
+    _ModuleList = Union[Sequence[Union[str, ModuleType]], None]
     _ModuleOrModuleList = Union[str, ModuleType, _ModuleList]
 
 if platform.python_implementation() == "CPython":
@@ -114,7 +114,7 @@ def _wrap_blocking(
     return wrapper
 
 
-def _resolve_module_paths(modules: list[str | ModuleType]) -> list[str]:
+def _resolve_module_paths(modules: Sequence[str | ModuleType]) -> list[str]:
     resolved: list[str] = []
     for module in modules:
         module_ = importlib.import_module(module) if isinstance(module, str) else module
@@ -184,17 +184,12 @@ class BlockBusterFunction:
         )
         self.can_block_predicate: Callable[..., bool] = can_block_predicate
         self.activated = False
-        self._scanned_modules: list[str] = []
-        if isinstance(scanned_modules, list):
-            _scanned_modules = scanned_modules
-        elif isinstance(scanned_modules, (str, ModuleType)):
-            _scanned_modules = [scanned_modules]
+        if isinstance(scanned_modules, (str, ModuleType)):
+            _scanned_modules: Sequence[str | ModuleType] = [scanned_modules]
         else:
-            _scanned_modules = []
+            _scanned_modules = scanned_modules or []
         self._scanned_modules = _resolve_module_paths(_scanned_modules)
-        self._excluded_modules: list[str] = _resolve_module_paths(
-            excluded_modules or []
-        )
+        self._excluded_modules = _resolve_module_paths(excluded_modules or [])
 
     def activate(self) -> BlockBusterFunction:
         """Activate the blocking detection."""
@@ -462,7 +457,10 @@ def _get_io_wrapped_functions(
         "io.BufferedWriter.write": BlockBusterFunction(
             None,
             "io.BufferedWriter.write",
-            can_block_functions=[("_pytest/assertion/rewrite.py", {"_write_pyc"})],
+            can_block_functions=[
+                ("<frozen importlib._bootstrap>", {"_find_and_load"}),
+                ("_pytest/assertion/rewrite.py", {"_write_pyc"}),
+            ],
             can_block_predicate=file_write_exclude,
             scanned_modules=modules,
             excluded_modules=excluded_modules,
@@ -594,6 +592,7 @@ def _get_lock_wrapped_functions(
                 ("threading.py", {"start"}),
                 ("/pydevd.py", {"_do_wait_suspend"}),
                 ("asyncio/base_events.py", {"shutdown_default_executor"}),
+                ("concurrent/futures/thread.py", {"submit"}),
             ],
             scanned_modules=modules,
             excluded_modules=excluded_modules,
@@ -602,7 +601,10 @@ def _get_lock_wrapped_functions(
             _thread.LockType,
             "acquire_lock",
             can_block_predicate=lock_acquire_exclude,
-            can_block_functions=[("threading.py", {"start"})],
+            can_block_functions=[
+                ("threading.py", {"start"}),
+                ("concurrent/futures/thread.py", {"submit"}),
+            ],
             scanned_modules=modules,
             excluded_modules=excluded_modules,
         ),
